Very Simple Asynchronous Tasks
------------------------------

A small library that allows asynchronous tasks to be executed.  Useful for
web applications when you need a task to run in the background.

Example
-------

::

    pip install vsat

